==> knox-1.6.0-src.zip: knox-1.6.0/gateway-service-hbase/src/main/java/org/apache/knox/gateway/hbase/HBaseUIDispatch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.hbase;

import org.apache.http.client.methods.HttpUriRequest;
import org.apache.knox.gateway.dispatch.DefaultDispatch;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

public class HBaseUIDispatch extends DefaultDispatch {
  @Override
  protected void executeRequest(HttpUriRequest outboundRequest, HttpServletRequest inboundRequest,
      HttpServletResponse outboundResponse) throws IOException {
    // partial workaround for KNOX-799
    outboundRequest = HBaseRequestUtil.fixTrailingSlash(outboundRequest, inboundRequest);
    super.executeRequest(outboundRequest, inboundRequest, outboundResponse);
  }
}

==> knox-2.0.0-src.zip: knox-2.0.0/gateway-service-hbase/src/main/java/org/apache/knox/gateway/hbase/HBaseUIDispatch.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.hbase;

import org.apache.http.client.methods.HttpUriRequest;
import org.apache.knox.gateway.dispatch.ConfigurableDispatch;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

public class HBaseUIDispatch extends ConfigurableDispatch {
  @Override
  protected void executeRequest(HttpUriRequest outboundRequest, HttpServletRequest inboundRequest,
      HttpServletResponse outboundResponse) throws IOException {
    // partial workaround for KNOX-799
    outboundRequest = HBaseRequestUtil.fixTrailingSlash(outboundRequest, inboundRequest);
    super.executeRequest(outboundRequest, inboundRequest, outboundResponse);
  }
}
